TraitsUI Documentation
======================

.. toctree::
    :maxdepth: 2
    :glob:

    traitsui_user_manual/index
    api/index
    tutorials/index
    demos/index
    changelog

.. include:: ../../README.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
